@@ -20,8 +20,24 @@ def cookiecutter_template_dir():
 def create(project_name, output_dir=".", setup=None, force=False):
     """
     Creates a whisk project.
+
+    Parameters
+    ----------
+    project_name : str
+        Name of the directory to create for the project.
+
+    output_dir : str, optional
+        Path to create the directory. Default is the current working directory.
+
+    setup : bool, optional
+        Whether to run the post-creation setup command. By default this is `True`. If `False`, only the directory structure is created.
+
+    force : bool, optional
+        Recreates the project directory if it exists. Default is `False`.
     """
-    whisk_version = "whisk>={}".format(whisk.__version__)
+    # Locks to a specific version as earlier and later versions of whisk could expect a different
+    # template structure.
+    whisk_version = "whisk=={}".format(whisk.__version__)
     # `whisk_dependency` is more flexible (for example, specifying a local install)
     # than `whisk_install_requires` and is used in testing to require the local version of whisk.
     extra_content = {
